@@ -7,14 +7,14 @@ SUFFIX = ".md4"
 @gethashcli(NAME)
 def main(check, files, **kwargs):
     try:
-        from Crypto.Hash import MD4 as H
+        from Crypto.Hash.MD4 import new as H
     except ImportError:
         import sys
 
         sys.stderr.write("PyCryptodome is not found.\n")
         sys.exit(-1)
 
-    script_main(H.new(), SUFFIX, check, files, **kwargs)
+    script_main(H(), SUFFIX, check, files, **kwargs)
 
 
 if __name__ == "__main__":
